pub fn decode_execute_response(
bytes: &[u8],
) -> Result<(ExecuteTaskResponse, Option<RecordBatch>)>Expand description
Decode an execute-task response body into its metadata and optional output batch.
pub fn decode_execute_response(
bytes: &[u8],
) -> Result<(ExecuteTaskResponse, Option<RecordBatch>)>Decode an execute-task response body into its metadata and optional output batch.